% FILAMENTORIENTATION_MULTI   Estimate filament's orientations with orientation space representation
%
% SYNOPSIS:
%   out = filamentorientation_multi(image,n_orientations,scale,bandwidth)
%
% PARAMETERS:
%   n_orientations
%      Number of analyzed orientations (odd number)
%   scale
%      Scale in pixels at which the orientation is evaluated 
%   bandwidth
%      Bandwidth of the orientation space filters (default: 0.8 * (1/scale))

% (C) Copyright 2015               Quantitative Imaging Group
%     All rights reserved          Faculty of Applied Physics
%                                  Delft University of Technology
%                                  Lorentzweg 1
%                                  2628 CJ Delft
%                                  The Netherlands
%
% Robert Nieuwenhuizen, April 2015


function varargout = filamentorientation_multi(varargin)

d = struct('menu','Co-orientation',...
           'display','Filamentorienation_multi',...
           'inparams',struct('name',       {'in',                   'n_orientations',           'scale',                'bw'},...
                             'description',{'Image',                'Number of orientations',   'Orientation scale',    'Bandwidth'},...
                             'type',       {'image',                'array',                    'array',                'array'},...
                             'dim_check',  {2,                      0,                          0,                      0},...
                             'range_check',{[],                     'N+',                       'R+',                   'R'},...
                             'required',   {1,                      1,                          0,                      0},...
                             'default',    {[],                     [],                         5,                      0.8}...
                              ),...
           'outparams',struct('name',{'orientationspace_out'},...
                              'description',{'Output'},...
                              'type',{'array'}...
                              )...
           );       

if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      varargout{1} = d;
      return
   end
end

try
   [in,n_orientations,ornt_scale,ornt_bandwidth] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error('Parameter parsing was unsuccessful.')
   end
end       

out = orientationspace(in,floor(n_orientations/2),1/ornt_scale,ornt_bandwidth);
out = abs(out); 
out = out-min(out,[],3);    % Baseline correction as of 06-02-2015
out = out*(in./sum(out,[],3));
varargout{1} = out;
